#ifndef _dashsensor_device_h__
#define _dashsensor_device_h__

#include <QGroupBox>
#include <QLabel>
#include <QGridLayout>
#include <QString>
#include <QList>
#include <QMap>
#include <QPushButton>
#include <QCheckBox>

#include "TenkiDevice.h"
#include "MinMaxResettable.h"
#include "DashSensor.h"
#include "ConfigCheckbox.h"
#include "EditButton.h"

class DashSensorDevice : public DashSensor
{
	Q_OBJECT

	public:
		DashSensorDevice(TenkiDevice *td);
		~DashSensorDevice();

		TenkiDevice *tenki_device;
		void refresh();

	private slots:
		void calibrateClicked(int id);
		void infoClicked(bool);
		void cbAllBigviewChanged(int state);
		void cbAllGraphChanged(int state);
		void cbCalibrateChanged(int id, int checked);

	private:
		void addChannel(int channel, int row);
		QString base_title;
		QGridLayout *layout;
		QList<QLabel*> descriptions;
		QList<QLabel*> values;
		QList<QLabel*> units;
		QList<MinMaxResettable*> minimums;
		QList<MinMaxResettable*> maximums;
		QList<int> channel_id;
		QList<int> chip_ids;

		QPushButton *infobtn;
		QCheckBox *cb_all_graph, *cb_all_bigview;

		QList<ConfigCheckbox*> bigviewCheckboxes;
		QList<ConfigCheckbox*> graphCheckboxes;
		QList<EditButton*> calButtons;
		QList<QLabel*> attentionLabels;

		void recolorizeThermocouple(void);
		void syncAttentionIcons(void);
		int prev_iec;
};

#endif

